@@ -20,7 +20,7 @@
 #include "backendloader.h"
 #include "backendloaderadaptor.h"
 #include "backenddbuswrapper.h"
-#include "debug_p.h"
+#include "kscreen_backendLauncher_debug.h"
 #include "src/abstractbackend.h"
 #include "src/backendmanager_p.h"
 
@@ -63,7 +63,7 @@ bool BackendLoader::init()
 {
     QDBusConnection dbus = QDBusConnection::sessionBus();
     new BackendLoaderAdaptor(this);
-    if (!dbus.registerObject(QLatin1String("/"), this, QDBusConnection::ExportAdaptors)) {
+    if (!dbus.registerObject(QStringLiteral("/"), this, QDBusConnection::ExportAdaptors)) {
         qCWarning(KSCREEN_BACKEND_LAUNCHER) << "Failed to export backend to DBus: another launcher already running?";
         qCWarning(KSCREEN_BACKEND_LAUNCHER) << dbus.lastError().message();
         return false;
